from django.conf import settings
from django.db.models.signals import class_prepared, pre_init


def add_db_prefix(sender, **kwargs):
    prefix = getattr(settings, "DB_PREFIX", None)
    if prefix and not sender._meta.db_table.startswith(prefix):
        sender._meta.db_table = prefix + sender._meta.db_table


pre_init.connect(add_db_prefix)
class_prepared.connect(add_db_prefix)



# -*- coding: utf-8 -*-
import os.path
from distutils.core import setup


def read(fname):
    with open(os.path.join(os.path.dirname(__file__), fname)) as f:
        return f.read()


setup(
    name='django-db-prefix',
    version='1.0.1',
    keywords='django database',
    author=u'Ben Slavin <benjamin.slavin@gmail.com>, Denilson Sá <denilsonsa@gmail.com>, Fingul <fingul@gmail.com>',
    packages=['django_db_prefix'],
    url='https://github.com/fingul/django-db-prefix',
    license='BSD licence, see LICENCE',
    description='Allow specification of a global, per-app or per-model database table name prefix.',
    long_description=read('README.md'),
    requires=[
        'Django',
    ],
    classifiers=[
        'Development Status :: 5 - Production/Stable',
        'Framework :: Django',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: BSD License',
        'Programming Language :: Python',
        'Programming Language :: Python :: 2.7',
        'Programming Language :: Python :: 3',
        'Topic :: Database',
    ]
)
